import vega from 'vega';
import vegaLite from 'vega-lite';
import vl from 'vega-lite-api';
import { Handler } from 'vega-tooltip';
import { config } from './config';
import { getData } from './getData';
import { viz } from './viz';

vl.register(vega, vegaLite, {
  view: { renderer: 'svg' },
  init: view => {
    view.tooltip(new Handler().call);
  }
});

//Enter ingredients to filter on
const ingredient1 = "egg white"
const ingredient2 = ""
const ingredient3 = ""
const ingredient4 = ""
const ingredient5 = ""

//Enter number of slices to include in order to view the top n results
const nSlices = 100;

const title = "Common Ingredients Paired With: " + ingredient1 +
      (ingredient2 == "" ? "" : ", " + ingredient2) + 
      (ingredient3 == "" ? "" : ", " + ingredient3) + 
      (ingredient4 == "" ? "" : ", " + ingredient4) + 
      (ingredient5 == "" ? "" : ", " + ingredient5);

console.log(title);

const run = async () => {
  let data = await getData();
  
  data = data.filter(x =>
    x.Ingredients.toLowerCase().includes(ingredient1.toLowerCase())
  );
  data = data.filter(x =>
    x.Ingredients.toLowerCase().includes(ingredient2.toLowerCase())
  );
  data = data.filter(x =>
    x.Ingredients.toLowerCase().includes(ingredient3.toLowerCase())
  );
  data = data.filter(x =>
    x.Ingredients.toLowerCase().includes(ingredient4.toLowerCase())
  );
  data = data.filter(x =>
    x.Ingredients.toLowerCase().includes(ingredient5.toLowerCase())
  );

  data = data.slice(0, nSlices);
  
  const marks = viz
    .data(data)
    .width(window.innerWidth)
    .height(window.innerHeight)
    .autosize({ type: 'fit', contains: 'padding' })
    .config(config)
    .title(title);

  document.body.appendChild(await marks.render());
};
run();
